# Get started!

Welcome to Rapunzel, a modern development environment for Python and R. Here are a few handy keyboard shortcuts.


## Working with project folders and files

- [`Ctrl+Shift+O`: Open project folder](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`: Open file from project folders](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`: Create empty document](opensesame://event.ide_new_file)


## Doing things quickly

- [`Ctrl+Shift+P`: Activate command palette](opensesame://event.command_palette_activate)
- `Ctrl+R`: Jump to function or class


## Running code

- `F5`: Run project or file
- `F9`: Run selection, cell, or current line
